EasyExtend.langlets.p4d.p4dbase._child_iter

Package EasyExtend :: Package langlets :: Package p4d :: Module p4dbase :: Class _child_iter |
[hide private]
[frames] | no frames]

# Class _child_iter

    object --+
             |
            _child_iter

Instance Methods | [hide private]
__init__(self, name, tag, children) x.__init__(...) initializes x; see x.__class__.__doc__ for signature |
__iter__(self) |
next(self) |
_get_first(self) |
__getattr__(self, sub) |
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Properties | [hide private]
| first
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, name, tag, children) (Constructor) |
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

Property Details | [hide private]

### first Get Method: _get_first(self)